@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "google-this" "1.12"
+(define-package "google-this" "20250407.1500"
   "A set of functions and bindings to google under point."
   '((emacs "24.1"))
-  :url "https://github.com/Malabarba/emacs-google-this"
-  :commit "8a2e3ca5da6a8c89bfe99a21486c6c7db125dc84"
-  :revdesc "8a2e3ca5da6a"
+  :url "http://github.com/Malabarba/emacs-google-this"
+  :commit "abdcb565503844e2146de42ab5ba898e90a2bb09"
+  :revdesc "abdcb5655038"
   :keywords '("convenience" "hypermedia")
   :authors '(("Artur Malabarba" . "bruce.connor.am@gmail.com"))
   :maintainers '(("Artur Malabarba" . "bruce.connor.am@gmail.com")))
